@@ -255,10 +255,9 @@ src_present_real_sro_for_speech (SRObject *obj, gchar *reason)
 	if (txt && txt[0])
 	{
 	    SRObjectRoles role;
-	    SRState state;
 	    sro_get_role (obj, &role, SR_INDEX_CONTAINER);
-	    sro_get_state (obj, &state, SR_INDEX_CONTAINER);
-	    if (state & SR_STATE_FOCUSED || strcmp (reason, "present") == 0)
+	    if (srl_is_object_focused (obj) || strcmp (reason, "present") == 0 ||
+		strcmp (reason, "object:context-switched") == 0)
 	    {
 		if ( role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
 		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, FALSE);
